==> webservices-osgi-2.3.1-b419-sources.jar: com/sun/xml/messaging/saaj/soap/StaxBridge.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.xml.messaging.saaj.soap;

import com.sun.xml.messaging.saaj.util.stax.SaajStaxWriter;

import javax.xml.namespace.QName;
import javax.xml.soap.SOAPException;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import org.jvnet.staxex.util.XMLStreamReaderToXMLStreamWriter;


/**
 * StaxBridge builds Envelope using a XMLStreamReaderToXMLStreamWriter 
 *
 * @author shih-chang.chen@oracle.com
 */
public abstract class StaxBridge {
	protected SaajStaxWriter saajWriter;
	protected XMLStreamReaderToXMLStreamWriter readerToWriter;
	protected XMLStreamReaderToXMLStreamWriter.Breakpoint breakpoint;
	
	
	public StaxBridge(SOAPPartImpl soapPart) throws SOAPException {
		readerToWriter = new XMLStreamReaderToXMLStreamWriter();
		saajWriter = new SaajStaxWriter(soapPart.message, soapPart.getSOAPNamespace());
	}

	public void bridgeEnvelopeAndHeaders() throws XMLStreamException {
		readerToWriter.bridge(breakpoint);
	}
	
	public void bridgePayload() throws XMLStreamException {
		readerToWriter.bridge(breakpoint);
	}

    abstract public XMLStreamReader getPayloadReader();

    abstract public QName getPayloadQName();
    
    abstract public String getPayloadAttributeValue(String attName) ;

    abstract public String getPayloadAttributeValue(QName attName) ;
}

==> webservices-osgi-3.0.0-sources.jar: com/sun/xml/messaging/saaj/soap/StaxBridge.java <==
/*
 * Copyright (c) 2013, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package com.sun.xml.messaging.saaj.soap;

import com.sun.xml.messaging.saaj.util.stax.SaajStaxWriter;

import javax.xml.namespace.QName;
import jakarta.xml.soap.SOAPException;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;
import org.jvnet.staxex.util.XMLStreamReaderToXMLStreamWriter;


/**
 * StaxBridge builds Envelope using a XMLStreamReaderToXMLStreamWriter 
 *
 * @author shih-chang.chen@oracle.com
 */
public abstract class StaxBridge {
	protected SaajStaxWriter saajWriter;
	protected XMLStreamReaderToXMLStreamWriter readerToWriter;
	protected XMLStreamReaderToXMLStreamWriter.Breakpoint breakpoint;
	
	
	public StaxBridge(SOAPPartImpl soapPart) throws SOAPException {
		readerToWriter = new XMLStreamReaderToXMLStreamWriter();
		saajWriter = new SaajStaxWriter(soapPart.message, soapPart.getSOAPNamespace());
	}

	public void bridgeEnvelopeAndHeaders() throws XMLStreamException {
		readerToWriter.bridge(breakpoint);
	}
	
	public void bridgePayload() throws XMLStreamException {
		readerToWriter.bridge(breakpoint);
	}

    abstract public XMLStreamReader getPayloadReader();

    abstract public QName getPayloadQName();
    
    abstract public String getPayloadAttributeValue(String attName) ;

    abstract public String getPayloadAttributeValue(QName attName) ;
}
